@@ -1,7 +1,7 @@
 use crate::fs::{Metadata, OpenOptions, Permissions};
 use crate::fs_utf8::from_utf8;
 use camino::Utf8Path;
-use cap_primitives::{ambient_authority, AmbientAuthority};
+use cap_primitives::AmbientAuthority;
 #[cfg(not(windows))]
 use io_extras::os::rustix::{AsRawFd, FromRawFd, IntoRawFd, RawFd};
 #[cfg(not(windows))]
@@ -36,13 +36,11 @@ pub struct File {
 impl File {
     /// Constructs a new instance of `Self` from the given [`std::fs::File`].
     ///
-    /// # Ambient Authority
-    ///
-    /// [`std::fs::File`] is not sandboxed and may access any path that the
-    /// host process has access to.
+    /// This grants access the resources the `std::fs::File` instance
+    /// already has access to.
     #[inline]
-    pub fn from_std(std: fs::File, ambient_authority: AmbientAuthority) -> Self {
-        Self::from_cap_std(crate::fs::File::from_std(std, ambient_authority))
+    pub fn from_std(std: fs::File) -> Self {
+        Self::from_cap_std(crate::fs::File::from_std(std))
     }
 
     /// Constructs a new instance of `Self` from the given `cap_std::fs::File`.
@@ -163,7 +161,7 @@ impl File {
 impl FromRawFd for File {
     #[inline]
     unsafe fn from_raw_fd(fd: RawFd) -> Self {
-        Self::from_std(fs::File::from_raw_fd(fd), ambient_authority())
+        Self::from_std(fs::File::from_raw_fd(fd))
     }
 }
 
@@ -171,7 +169,7 @@ impl FromRawFd for File {
 impl FromFd for File {
     #[inline]
     fn from_fd(fd: OwnedFd) -> Self {
-        Self::from_std(fs::File::from_fd(fd), ambient_authority())
+        Self::from_std(fs::File::from_fd(fd))
     }
 }
 
@@ -179,7 +177,7 @@ impl FromFd for File {
 impl FromRawHandle for File {
     #[inline]
     unsafe fn from_raw_handle(handle: RawHandle) -> Self {
-        Self::from_std(fs::File::from_raw_handle(handle), ambient_authority())
+        Self::from_std(fs::File::from_raw_handle(handle))
     }
 }
 
@@ -187,7 +185,7 @@ impl FromRawHandle for File {
 impl FromHandle for File {
     #[inline]
     fn from_handle(handle: OwnedHandle) -> Self {
-        Self::from_std(fs::File::from_handle(handle), ambient_authority())
+        Self::from_std(fs::File::from_handle(handle))
     }
 }
 
